pub struct StakingPosition {
pub position_id: Pubkey,
pub amount: u64,
pub start_time: i64,
pub duration_days: u16,
pub unlock_time: i64,
pub apy_bps: u16,
pub auto_compound: bool,
pub accrued_yield: u64,
}Expand description
Staking position details
Fields
position_id: Pubkeyamount: u64start_time: i64duration_days: u16unlock_time: i64apy_bps: u16auto_compound: boolaccrued_yield: u64Trait Implementations
Sourceimpl BorshDeserialize for StakingPosition
impl BorshDeserialize for StakingPosition
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for StakingPosition
impl BorshSerialize for StakingPosition
Sourceimpl Clone for StakingPosition
impl Clone for StakingPosition
Sourcefn clone(&self) -> StakingPosition
fn clone(&self) -> StakingPosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for StakingPosition
impl RefUnwindSafe for StakingPosition
impl Send for StakingPosition
impl Sync for StakingPosition
impl Unpin for StakingPosition
impl UnsafeUnpin for StakingPosition
impl UnwindSafe for StakingPosition