pub struct YieldRecommendation {
pub current_apy: u16,
pub recommended_action: RecommendedAction,
pub projected_apy: u16,
pub reasoning: String,
}Expand description
Yield optimization recommendation
Fields
current_apy: u16recommended_action: RecommendedActionprojected_apy: u16reasoning: StringTrait Implementations
Sourceimpl BorshDeserialize for YieldRecommendation
impl BorshDeserialize for YieldRecommendation
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for YieldRecommendation
impl BorshSerialize for YieldRecommendation
Sourceimpl Clone for YieldRecommendation
impl Clone for YieldRecommendation
Sourcefn clone(&self) -> YieldRecommendation
fn clone(&self) -> YieldRecommendation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for YieldRecommendation
impl RefUnwindSafe for YieldRecommendation
impl Send for YieldRecommendation
impl Sync for YieldRecommendation
impl Unpin for YieldRecommendation
impl UnsafeUnpin for YieldRecommendation
impl UnwindSafe for YieldRecommendation