pub struct LoopFingerprint(/* private fields */);Expand description
A Loop fingerprint (one-way hash of card_id)
Format: loop_fp_{64 hex characters}
This type ensures fingerprints are always properly formatted and cannot be confused with raw card IDs.
Implementations
Sourceimpl LoopFingerprint
impl LoopFingerprint
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Convert to owned string
Sourcepub fn is_valid_format(s: &str) -> bool
pub fn is_valid_format(s: &str) -> bool
Check if a string is a valid Loop fingerprint format